==> opencc-doc-1.1.8-2-x86_64.pkg.tar.zst: usr/share/opencc/doc/html/search/all_2.js <==
var searchData=
[
  ['c_0',['C',['../index.html#autotoc_md11',1,'C'],['../index.html#autotoc_md10',1,'C++']]],
  ['c_20api_1',['OpenCC C API',['../group__opencc__c__api.html',1,'']]],
  ['c_20comprehensive_20api_2',['OpenCC C++ Comprehensive API',['../group__opencc__cpp__api.html',1,'']]],
  ['c_20simple_20api_3',['OpenCC C++ Simple API',['../group__opencc__simple__api.html',1,'']]],
  ['change_20history_20版本歷史_4',['Change History 版本歷史',['../index.html#autotoc_md28',1,'']]],
  ['chinese_20convert_20開放中文轉換_5',['Open Chinese Convert 開放中文轉換',['../index.html',1,'']]],
  ['cmake_6',['Build with CMake',['../index.html#autotoc_md17',1,'']]],
  ['cmdlineoutput_7',['CmdLineOutput',['../class_cmd_line_output.html',1,'']]],
  ['command_20line_8',['Command Line',['../index.html#autotoc_md12',1,'']]],
  ['comprehensive_20api_9',['OpenCC C++ Comprehensive API',['../group__opencc__cpp__api.html',1,'']]],
  ['config_10',['Config',['../classopencc_1_1_config.html',1,'opencc']]],
  ['configurations_20配置文件_11',['Configurations 配置文件',['../index.html#autotoc_md14',1,'']]],
  ['contributors_20貢獻者_12',['Contributors 貢獻者',['../index.html#autotoc_md30',1,'']]],
  ['conversion_13',['Conversion',['../classopencc_1_1_conversion.html',1,'opencc']]],
  ['conversionchain_14',['ConversionChain',['../classopencc_1_1_conversion_chain.html',1,'opencc']]],
  ['convert_15',['Convert',['../classopencc_1_1_simple_converter.html#a0042dba7fe92bee2cadb4d7a8cbec929',1,'opencc::SimpleConverter::Convert(const std::string &amp;input) const'],['../classopencc_1_1_simple_converter.html#a3bc95485e6b8c5bca6b728f557efd98a',1,'opencc::SimpleConverter::Convert(const char *input) const'],['../classopencc_1_1_simple_converter.html#a63baff1214203c8835105b5167daba43',1,'opencc::SimpleConverter::Convert(const char *input, size_t length) const'],['../classopencc_1_1_simple_converter.html#ac9eb53d7dbecf687e0d43eaaf9bf2bd1',1,'opencc::SimpleConverter::Convert(const char *input, char *output) const'],['../classopencc_1_1_simple_converter.html#a63f5dbba323443bd42772d4c5c77b313',1,'opencc::SimpleConverter::Convert(const char *input, size_t length, char *output) const']]],
  ['convert_20開放中文轉換_16',['Open Chinese Convert 開放中文轉換',['../index.html',1,'']]],
  ['convertdictionary_17',['ConvertDictionary',['../group__opencc__cpp__api.html#ga84f945fa756d6f7f8bae6700586e5cba',1,'opencc']]],
  ['converter_18',['Converter',['../classopencc_1_1_converter.html',1,'opencc']]]
];

==> opencc-doc-1.1.9-1-x86_64.pkg.tar.zst: usr/share/opencc/doc/html/search/all_2.js <==
var searchData=
[
  ['c_0',['C',['..//build/opencc/src/OpenCC/README.md#autotoc_md13',1,'C'],['..//build/opencc/src/OpenCC/README.md#autotoc_md12',1,'C++']]],
  ['c_20api_1',['OpenCC C API',['../group__opencc__c__api.html',1,'']]],
  ['c_20comprehensive_20api_2',['OpenCC C++ Comprehensive API',['../group__opencc__cpp__api.html',1,'']]],
  ['c_20simple_20api_3',['OpenCC C++ Simple API',['../group__opencc__simple__api.html',1,'']]],
  ['change_20history_20版本歷史_4',['Change History 版本歷史',['..//build/opencc/src/OpenCC/README.md#autotoc_md30',1,'']]],
  ['chinese_20convert_20開放中文轉換_5',['Open Chinese Convert 開放中文轉換',['..//build/opencc/src/OpenCC/README.md#autotoc_md0',1,'']]],
  ['cmake_6',['Build with CMake',['..//build/opencc/src/OpenCC/README.md#autotoc_md19',1,'']]],
  ['cmdlineoutput_7',['CmdLineOutput',['../class_cmd_line_output.html',1,'']]],
  ['command_20line_8',['Command Line',['..//build/opencc/src/OpenCC/README.md#autotoc_md14',1,'']]],
  ['comprehensive_20api_9',['OpenCC C++ Comprehensive API',['../group__opencc__cpp__api.html',1,'']]],
  ['config_10',['Config',['../classopencc_1_1_config.html',1,'opencc']]],
  ['configurations_20配置文件_11',['Configurations 配置文件',['..//build/opencc/src/OpenCC/README.md#autotoc_md16',1,'']]],
  ['contributors_20貢獻者_12',['Contributors 貢獻者',['..//build/opencc/src/OpenCC/README.md#autotoc_md32',1,'']]],
  ['conversion_13',['Conversion',['../classopencc_1_1_conversion.html',1,'opencc']]],
  ['conversionchain_14',['ConversionChain',['../classopencc_1_1_conversion_chain.html',1,'opencc']]],
  ['convert_15',['Convert',['../classopencc_1_1_simple_converter.html#a0042dba7fe92bee2cadb4d7a8cbec929',1,'opencc::SimpleConverter::Convert(const std::string &amp;input) const'],['../classopencc_1_1_simple_converter.html#a3bc95485e6b8c5bca6b728f557efd98a',1,'opencc::SimpleConverter::Convert(const char *input) const'],['../classopencc_1_1_simple_converter.html#a63baff1214203c8835105b5167daba43',1,'opencc::SimpleConverter::Convert(const char *input, size_t length) const'],['../classopencc_1_1_simple_converter.html#ac9eb53d7dbecf687e0d43eaaf9bf2bd1',1,'opencc::SimpleConverter::Convert(const char *input, char *output) const'],['../classopencc_1_1_simple_converter.html#a63f5dbba323443bd42772d4c5c77b313',1,'opencc::SimpleConverter::Convert(const char *input, size_t length, char *output) const']]],
  ['convert_20開放中文轉換_16',['Open Chinese Convert 開放中文轉換',['..//build/opencc/src/OpenCC/README.md#autotoc_md0',1,'']]],
  ['convertdictionary_17',['ConvertDictionary',['../group__opencc__cpp__api.html#ga84f945fa756d6f7f8bae6700586e5cba',1,'opencc']]],
  ['converter_18',['Converter',['../classopencc_1_1_converter.html',1,'opencc']]]
];
